![spacy syllables](https://raw.githubusercontent.com/sloev/spacy_onnx_sentiment_english/master/.github/onix.webp) <a href="https://www.buymeacoffee.com/sloev" target="_blank"><img src="https://cdn.buymeacoffee.com/buttons/default-pink.png" alt="Buy Me A Coffee" height="51px" width="217px"></a>

![example workflow](https://github.com/sloev/spacy_onnx_sentiment_english/actions/workflows/test.yml/badge.svg) [![Latest Version](https://img.shields.io/pypi/v/spacy_onnx_sentiment_english.svg)](https://pypi.python.org/pypi/spacy_onnx_sentiment_english) [![Python Support](https://img.shields.io/pypi/pyversions/spacy_onnx_sentiment_english.svg)](https://pypi.python.org/pypi/spacy_onnx_sentiment_english)

# spacy sentiment english 


English sentiment component for spacy 2x and 3x

annotates sentences with negative, neutral, positive sentiment using a onnx model

## install

```bash
pip install spacy_onnx_sentiment_english
```

## usage

```python
import pytest
import spacy
from spacy_onnx_sentiment_english import OnnxSentimentEnglish

nlp = spacy.load("en_core_web_sm")
nlp.add_pipe("sentencizer")
nlp.add_pipe("onnx_sentiment_en", after="sentencizer")

sentences = [
    (sent.text, sent._.onnx_sentiment_en)
    for doc in nlp.pipe(
        [
            "i hate pasta on tuesdays",
            "i like movies on wednesdays",
            "i find your argument ridiculous",
            "soda with straws are my favorite",
        ]
    )
    for sent in doc.sents
]

assert sentences == [
    ("i hate pasta on tuesdays", "Negative"),
    ("i like movies on wednesdays", "Positive"),
    ("i find your argument ridiculous", "Negative"),
    ("soda with straws are my favorite", "Positive"),
]
```

## Dev setup / testing

### install

install the dev package and pyenv versions

```bash
$ pip install -e ".[dev]"
$ python -m spacy download en_core_web_sm
```

### run tests

```bash
$ black .
$ pytest -vvl
```


### Packaging and publishing

```bash
python3 -m pip install --upgrade build twine
python3 -m build
python3 -m twine upload dist/*
```