# -*- coding: utf-8 -*-
from typing import Optional
from spacy.tokens import Span
from spacy.language import Language
from spacy_onnx_sentiment_english import sentiment_inference
from spacy import util


@Language.factory(
    "onnx_sentiment_en",
    assigns=["span._.onnx_sentiment_en"],
    default_config={"threshold": 0.7, "lang": "en"},
    requires=["doc.sents"],
)
def __onnxSentimentEnglish_factory(nlp, name: str, lang: str, threshold):
    return OnnxSentimentEnglish(nlp, name, lang, threshold)


class OnnxSentimentEnglish:
    def __init__(
        self,
        nlp: Language,
        name: str = "onnx_sentiment_en",
        lang: Optional[str] = "en",
        threshold: float = 0.7,
    ):
        self.name = name
        self.inference_func = sentiment_inference.create_inference_function(
            threshold=threshold
        )

        if lang != "en":
            raise NotImplementedError(
                f"SpacySyllables has no support for language: {lang}"
            )

        Span.set_extension("onnx_sentiment_en", default=None, force=True)

    def __call__(self, doc):
        sentences = [str(sent) for sent in doc.sents]
        sentiments = self.inference_func(sentences)
        for sentence, sentiment in zip(doc.sents, sentiments):
            sentence._.set("onnx_sentiment_en", sentiment)
        return doc

    def pipe(self, stream, batch_size=1000):
        for docs in util.minibatch(stream, size=batch_size):
            sentences = [sent.text.lower() for doc in docs for sent in doc.sents]
            sentiments = self.inference_func(sentences)
            for doc in docs:
                for sent in doc.sents:
                    sentiment = sentiments.pop(0)
                    sent._.set("onnx_sentiment_en", sentiment)
                yield doc
