import onnx
import numpy as np
from onnxruntime import InferenceSession

from spacy_onnx_sentiment_english import models, util


__label_to_index = {"NEGATIVE": 0, "NEUTRAL": 1, "POSITIVE": 2}
__index_to_label = {v: k for k, v in __label_to_index.items()}


def create_inference_function(
    tokenizer_path=models.TOKENIZER_PATH,
    onnx_model_path=models.ONNX_PATH,
    threshold=0.7,
):
    with open(tokenizer_path, "r") as handle:
        tokenizer = util.tokenizer_from_json(handle.read())

    model_def = onnx.load(onnx_model_path)

    sess = InferenceSession(model_def.SerializeToString())

    def infer(texts):
        tokenized = tokenizer.texts_to_sequences(texts)

        padded_tokenized = util.pad_sequences(tokenized, maxlen=54)

        predictions = sess.run(None, {"Tokenized_Sent_Input:0": padded_tokenized})
        predictions = predictions[0]

        results = []
        for pred in predictions:
            if max(pred) < threshold:
                results.append("Neutral")
            else:
                predicted_token = np.argmax(pred)
                predicted_decoded = __index_to_label[predicted_token]
                results.append(predicted_decoded.lower().capitalize())
        return results

    return infer
